pub(super) struct CredentialFields {
username: Option<&'static str>,
password: Option<&'static str>,
address: Option<&'static str>,
}Expand description
The section field ids a category uses for the username, the password and the address the
credential belongs to. A slot the category does not have is None.
Fields
username: Option<&'static str>password: Option<&'static str>address: Option<&'static str>Auto Trait Implementations
impl Freeze for CredentialFields
impl RefUnwindSafe for CredentialFields
impl Send for CredentialFields
impl Sync for CredentialFields
impl Unpin for CredentialFields
impl UnsafeUnpin for CredentialFields
impl UnwindSafe for CredentialFields